const models = require("./models");
const AbstractClient = require('../../common/abstract_client')
const DetachDisksRequest = models.DetachDisksRequest;
const InquiryPriceRenewDisksResponse = models.InquiryPriceRenewDisksResponse;
const ResizeDiskRequest = models.ResizeDiskRequest;
const ModifyDiskAttributesResponse = models.ModifyDiskAttributesResponse;
const TerminateDisksRequest = models.TerminateDisksRequest;
const CreateSnapshotRequest = models.CreateSnapshotRequest;
const DescribeInstancesDiskNumRequest = models.DescribeInstancesDiskNumRequest;
const Placement = models.Placement;
const ModifySnapshotAttributeRequest = models.ModifySnapshotAttributeRequest;
const InquiryPriceRenewDisksRequest = models.InquiryPriceRenewDisksRequest;
const Price = models.Price;
const InquiryPriceCreateDisksResponse = models.InquiryPriceCreateDisksResponse;
const DiskConfig = models.DiskConfig;
const CreateSnapshotResponse = models.CreateSnapshotResponse;
const DeleteSnapshotsRequest = models.DeleteSnapshotsRequest;
const DescribeDiskConfigQuotaRequest = models.DescribeDiskConfigQuotaRequest;
const ModifyDisksRenewFlagResponse = models.ModifyDisksRenewFlagResponse;
const DiskChargePrepaid = models.DiskChargePrepaid;
const InquiryPriceResizeDiskRequest = models.InquiryPriceResizeDiskRequest;
const ApplySnapshotResponse = models.ApplySnapshotResponse;
const DescribeDisksResponse = models.DescribeDisksResponse;
const ModifySnapshotAttributeResponse = models.ModifySnapshotAttributeResponse;
const DeleteSnapshotsResponse = models.DeleteSnapshotsResponse;
const ModifyDisksRenewFlagRequest = models.ModifyDisksRenewFlagRequest;
const Filter = models.Filter;
const InquiryPriceCreateDisksRequest = models.InquiryPriceCreateDisksRequest;
const DescribeSnapshotsResponse = models.DescribeSnapshotsResponse;
const Snapshot = models.Snapshot;
const CreateDisksResponse = models.CreateDisksResponse;
const AttachDisksResponse = models.AttachDisksResponse;
const RenewDiskRequest = models.RenewDiskRequest;
const RenewDiskResponse = models.RenewDiskResponse;
const CreateDisksRequest = models.CreateDisksRequest;
const AttachDisksRequest = models.AttachDisksRequest;
const Tag = models.Tag;
const DescribeSnapshotsRequest = models.DescribeSnapshotsRequest;
const TerminateDisksResponse = models.TerminateDisksResponse;
const DescribeDiskConfigQuotaResponse = models.DescribeDiskConfigQuotaResponse;
const ModifyDiskAttributesRequest = models.ModifyDiskAttributesRequest;
const DescribeDisksRequest = models.DescribeDisksRequest;
const InquiryPriceResizeDiskResponse = models.InquiryPriceResizeDiskResponse;
const DescribeInstancesDiskNumResponse = models.DescribeInstancesDiskNumResponse;
const DetachDisksResponse = models.DetachDisksResponse;
const ResizeDiskResponse = models.ResizeDiskResponse;
const Disk = models.Disk;
const ApplySnapshotRequest = models.ApplySnapshotRequest;


/**
 * cbs client
 * @class
 */
class CbsClient extends AbstractClient {

    constructor(credential, region, profile) {
        super("cbs.tencentcloudapi.com", "2017-03-12", credential, region, profile);
    }
    
    /**
     * 本接口（CreateDisks）用于创建云硬盘。

* 预付费云盘的购买会预先扣除本次云盘购买所需金额，在调用本接口前请确保账户余额充足。
* 本接口支持传入数据盘快照来创建云盘，实现将快照数据复制到新购云盘上。
* 本接口为异步接口，当创建请求下发成功后会返回一个新建的云盘ID列表，此时云盘的创建并未立即完成。可以通过调用[DescribeDisks](/document/product/362/16315)接口根据DiskId查询对应云盘，如果能查到云盘，且状态为'UNATTACHED'或'ATTACHED'，则表示创建成功。
     * @param {CreateDisksRequest} req
     * @param {function(string, CreateDisksResponse):void} cb
     * @public
     */
    CreateDisks(req, cb) {
        let resp = new CreateDisksResponse();
        this.request("CreateDisks", req, resp, cb);
    }

    /**
     * 本接口（DetachDisks）用于解挂云硬盘。

* 支持批量操作，解挂挂载在同一主机上的多块云盘。如果多块云盘存在不允许解挂载的云盘，则操作不执行，以返回特定的错误码返回。
* 本接口为异步接口，当请求成功返回时，云盘并未立即从主机解挂载，可通过接口[DescribeDisks](/document/product/362/16315)来查询对应云盘的状态，如果云盘的状态由“ATTACHED”变为“UNATTACHED”，则为解挂载成功。
     * @param {DetachDisksRequest} req
     * @param {function(string, DetachDisksResponse):void} cb
     * @public
     */
    DetachDisks(req, cb) {
        let resp = new DetachDisksResponse();
        this.request("DetachDisks", req, resp, cb);
    }

    /**
     * 本接口（DescribeDiskConfigQuota）用于查询云硬盘配额。
     * @param {DescribeDiskConfigQuotaRequest} req
     * @param {function(string, DescribeDiskConfigQuotaResponse):void} cb
     * @public
     */
    DescribeDiskConfigQuota(req, cb) {
        let resp = new DescribeDiskConfigQuotaResponse();
        this.request("DescribeDiskConfigQuota", req, resp, cb);
    }

    /**
     * 本接口（ModifyDiskAttributes）用于修改云硬盘属性。

* 只支持修改弹性云盘的项目ID。随云主机创建的云硬盘项目ID与云主机联动。可以通过[DescribeDisks](/document/product/362/16315)接口查询，见输出参数中Portable字段解释。
* “云硬盘名称”仅为方便用户自己管理之用，腾讯云并不以此名称作为提交工单或是进行云盘管理操作的依据。
* 支持批量操作，如果传入多个云盘ID，则所有云盘修改为同一属性。如果存在不允许操作的云盘，则操作不执行，以特定错误码返回。
     * @param {ModifyDiskAttributesRequest} req
     * @param {function(string, ModifyDiskAttributesResponse):void} cb
     * @public
     */
    ModifyDiskAttributes(req, cb) {
        let resp = new ModifyDiskAttributesResponse();
        this.request("ModifyDiskAttributes", req, resp, cb);
    }

    /**
     * 本接口（DeleteSnapshots）用于删除快照。

* 快照必须处于NORMAL状态，快照状态可以通过[DescribeSnapshots](/document/product/362/15647)接口查询，见输出参数中SnapshotState字段解释。
* 支持批量操作。如果多个快照存在无法删除的快照，则操作不执行，以返回特定的错误码返回。
     * @param {DeleteSnapshotsRequest} req
     * @param {function(string, DeleteSnapshotsResponse):void} cb
     * @public
     */
    DeleteSnapshots(req, cb) {
        let resp = new DeleteSnapshotsResponse();
        this.request("DeleteSnapshots", req, resp, cb);
    }

    /**
     * 本接口（RenewDisk）用于续费云硬盘。

* 只支持预付费的云硬盘。云硬盘类型可以通过[DescribeDisks](/document/product/362/16315)接口查询，见输出参数中DiskChargeType字段解释。
* 支持与挂载实例一起续费的场景，需要在[DiskChargePrepaid](/document/product/362/15669#DiskChargePrepaid)参数中指定CurInstanceDeadline，此时会按对齐到子机续费后的到期时间来续费。
* 续费时请确保账户余额充足。可通过[DescribeAccountBalance](/document/product/378/4397)接口查询账户余额。
     * @param {RenewDiskRequest} req
     * @param {function(string, RenewDiskResponse):void} cb
     * @public
     */
    RenewDisk(req, cb) {
        let resp = new RenewDiskResponse();
        this.request("RenewDisk", req, resp, cb);
    }

    /**
     * 本接口（DescribeInstancesDiskNum）用于查询实例已挂载云硬盘数量。

* 支持批量操作，当传入多个云服务器实例ID，返回结果会分别列出每个云服务器挂载的云硬盘数量。
     * @param {DescribeInstancesDiskNumRequest} req
     * @param {function(string, DescribeInstancesDiskNumResponse):void} cb
     * @public
     */
    DescribeInstancesDiskNum(req, cb) {
        let resp = new DescribeInstancesDiskNumResponse();
        this.request("DescribeInstancesDiskNum", req, resp, cb);
    }

    /**
     * 本接口（InquiryPriceCreateDisks）用于创建云硬盘询价。

* 支持查询创建多块云硬盘的价格，此时返回结果为总价格。
     * @param {InquiryPriceCreateDisksRequest} req
     * @param {function(string, InquiryPriceCreateDisksResponse):void} cb
     * @public
     */
    InquiryPriceCreateDisks(req, cb) {
        let resp = new InquiryPriceCreateDisksResponse();
        this.request("InquiryPriceCreateDisks", req, resp, cb);
    }

    /**
     * 本接口（InquiryPriceResizeDisk）用于扩容云硬盘询价。

* 只支持预付费模式的云硬盘扩容询价。
     * @param {InquiryPriceResizeDiskRequest} req
     * @param {function(string, InquiryPriceResizeDiskResponse):void} cb
     * @public
     */
    InquiryPriceResizeDisk(req, cb) {
        let resp = new InquiryPriceResizeDiskResponse();
        this.request("InquiryPriceResizeDisk", req, resp, cb);
    }

    /**
     * 本接口（ApplySnapshot）用于回滚快照到原云硬盘。

* 仅支持回滚到原云硬盘上。对于数据盘快照，如果您需要复制快照数据到其它云硬盘上，请使用[CreateDisks](/document/product/362/16312)接口创建新的弹性云盘，将快照数据复制到新购云盘上。 
* 用于回滚的快照必须处于NORMAL状态。快照状态可以通过[DescribeSnapshots](/document/product/362/15647)接口查询，见输出参数中SnapshotState字段解释。
* 如果是弹性云盘，则云盘必须处于未挂载状态，云硬盘挂载状态可以通过[DescribeDisks](/document/product/362/16315)接口查询，见Attached字段解释；如果是随云主机一起购买的非弹性云盘，则云主机必须处于关机状态，云主机状态可以通过[DescribeInstancesStatus](/document/product/213/15738)接口查询。
     * @param {ApplySnapshotRequest} req
     * @param {function(string, ApplySnapshotResponse):void} cb
     * @public
     */
    ApplySnapshot(req, cb) {
        let resp = new ApplySnapshotResponse();
        this.request("ApplySnapshot", req, resp, cb);
    }

    /**
     * 本接口（ModifySnapshotAttribute）用于修改指定快照的属性。

* 当前仅支持修改快照名称及将非永久快照修改为永久快照。
* “快照名称”仅为方便用户自己管理之用，腾讯云并不以此名称作为提交工单或是进行快照管理操作的依据。
     * @param {ModifySnapshotAttributeRequest} req
     * @param {function(string, ModifySnapshotAttributeResponse):void} cb
     * @public
     */
    ModifySnapshotAttribute(req, cb) {
        let resp = new ModifySnapshotAttributeResponse();
        this.request("ModifySnapshotAttribute", req, resp, cb);
    }

    /**
     * 本接口（TerminateDisks）用于退还云硬盘。

* 当前仅支持退还包年包月云盘。
* 支持批量操作，每次请求批量云硬盘的上限为50。如果批量云盘存在不允许操作的，请求会以特定错误码返回。
     * @param {TerminateDisksRequest} req
     * @param {function(string, TerminateDisksResponse):void} cb
     * @public
     */
    TerminateDisks(req, cb) {
        let resp = new TerminateDisksResponse();
        this.request("TerminateDisks", req, resp, cb);
    }

    /**
     * 本接口（DescribeDisks）用于查询云硬盘列表。

* 可以根据云硬盘ID、云硬盘类型或者云硬盘状态等信息来查询云硬盘的详细信息，不同条件之间为与(AND)的关系，过滤信息详细请见过滤器`Filter`。
* 如果参数为空，返回当前用户一定数量（`Limit`所指定的数量，默认为20）的云硬盘列表。
     * @param {DescribeDisksRequest} req
     * @param {function(string, DescribeDisksResponse):void} cb
     * @public
     */
    DescribeDisks(req, cb) {
        let resp = new DescribeDisksResponse();
        this.request("DescribeDisks", req, resp, cb);
    }

    /**
     * 本接口（ModifyDisksRenewFlag）用于修改云硬盘续费标识，支持批量修改。
     * @param {ModifyDisksRenewFlagRequest} req
     * @param {function(string, ModifyDisksRenewFlagResponse):void} cb
     * @public
     */
    ModifyDisksRenewFlag(req, cb) {
        let resp = new ModifyDisksRenewFlagResponse();
        this.request("ModifyDisksRenewFlag", req, resp, cb);
    }

    /**
     * 本接口（DescribeSnapshots）用于查询快照的详细信息。

* 根据快照ID、创建快照的云硬盘ID、创建快照的云硬盘类型等对结果进行过滤，不同条件之间为与(AND)的关系，过滤信息详细请见过滤器`Filter`。
*  如果参数为空，返回当前用户一定数量（`Limit`所指定的数量，默认为20）的快照列表。
     * @param {DescribeSnapshotsRequest} req
     * @param {function(string, DescribeSnapshotsResponse):void} cb
     * @public
     */
    DescribeSnapshots(req, cb) {
        let resp = new DescribeSnapshotsResponse();
        this.request("DescribeSnapshots", req, resp, cb);
    }

    /**
     * 本接口（AttachDisks）用于挂载云硬盘。

* 支持批量操作，将多块云盘挂载到同一云主机。如果多个云盘存在不允许挂载的云盘，则操作不执行，以返回特定的错误码返回。
* 本接口为异步接口，当挂载云盘的请求成功返回时，表示后台已发起挂载云盘的操作，可通过接口[DescribeDisks](/document/product/362/16315)来查询对应云盘的状态，如果云盘的状态由“ATTACHING”变为“ATTACHED”，则为挂载成功。
     * @param {AttachDisksRequest} req
     * @param {function(string, AttachDisksResponse):void} cb
     * @public
     */
    AttachDisks(req, cb) {
        let resp = new AttachDisksResponse();
        this.request("AttachDisks", req, resp, cb);
    }

    /**
     * 本接口（ResizeDisk）用于扩容云硬盘。

* 只支持扩容弹性云盘。云硬盘类型可以通过[DescribeDisks](/document/product/362/16315)接口查询，见输出参数中Portable字段解释。随云主机创建的云硬盘需通过[ResizeInstanceDisks](/document/product/213/15731)接口扩容。
* 本接口为异步接口，接口成功返回时，云盘并未立即扩容到指定大小，可通过接口[DescribeDisks](/document/product/362/16315)来查询对应云盘的状态，如果云盘的状态为“EXPANDING”，表示正在扩容中，当状态变为“UNATTACHED”，表示扩容完成。 
     * @param {ResizeDiskRequest} req
     * @param {function(string, ResizeDiskResponse):void} cb
     * @public
     */
    ResizeDisk(req, cb) {
        let resp = new ResizeDiskResponse();
        this.request("ResizeDisk", req, resp, cb);
    }

    /**
     * 本接口（CreateSnapshot）用于对指定云盘创建快照。

* 只有具有快照能力的云硬盘才能创建快照。云硬盘是否具有快照能力可由[DescribeDisks](/document/product/362/16315)接口查询，见SnapshotAbility字段。
* 可创建快照数量限制见[产品使用限制](https://cloud.tencent.com/doc/product/362/5145)。
     * @param {CreateSnapshotRequest} req
     * @param {function(string, CreateSnapshotResponse):void} cb
     * @public
     */
    CreateSnapshot(req, cb) {
        let resp = new CreateSnapshotResponse();
        this.request("CreateSnapshot", req, resp, cb);
    }

    /**
     * 本接口（InquiryPriceRenewDisks）用于续费云硬盘询价。

* 只支持查询预付费模式的弹性云盘续费价格。
* 支持与挂载实例一起续费的场景，需要在[DiskChargePrepaid](/document/product/362/15669#DiskChargePrepaid)参数中指定CurInstanceDeadline，此时会按对齐到实例续费后的到期时间来续费询价。
* 支持为多块云盘指定不同的续费时长，此时返回的价格为多块云盘续费的总价格。
     * @param {InquiryPriceRenewDisksRequest} req
     * @param {function(string, InquiryPriceRenewDisksResponse):void} cb
     * @public
     */
    InquiryPriceRenewDisks(req, cb) {
        let resp = new InquiryPriceRenewDisksResponse();
        this.request("InquiryPriceRenewDisks", req, resp, cb);
    }


}
module.exports = CbsClient;
